@@ -130,6 +130,10 @@ class DiffWriter(object):
             self.chunks = []
         self.chunks = [newstuff[-1]]
 
+    def writelines(self, lines):
+        for line in lines:
+            self.write(line)
+
     def _writeline(self, line):
         item = self.lp.parse_line(line)
         bad_ws_match = None
