@@ -153,10 +153,11 @@ def compact_ancestors(descendants, ancestors, exceptions=()):
     return new_ancestors
 
 def get_rev_info(rev_id, source):
-    """Return the committer, message, and date of a revision."""
+    """Return the committer, message, nick and date of a revision."""
     committer = None
     message = None
     date = None
+    nick = None
     if rev_id == 'null:':
         return None, 'Null Revision', None, None
     try:
@@ -201,13 +202,16 @@ class Grapher(object):
         self.graph = self.branch.repository.get_graph(other_repo)
         revision_a = self.branch.last_revision()
         self.scan_graph(revision_a, revision_b)
-        self.n_history = branch.revision_history()
+        self.n_history = list(self.graph.iter_lefthand_ancestry(revision_a))
+        self.n_history.reverse()
         self.n_revnos = branch.get_revision_id_to_revno_map()
         self.distances = node_distances(self.descendants, self.ancestors,
                                         self.root)
         if other_branch is not None:
             self.base = select_farthest(self.distances, self.common)
-            self.m_history = other_branch.revision_history()
+            self.m_history = self.graph.iter_lefthand_ancestry(revision_b)
+            self.m_history = list(self.m_history)
+            self.m_history.reverse()
             self.m_revnos = other_branch.get_revision_id_to_revno_map()
             self.new_base = self.graph.find_unique_lca(revision_a,
                                                        revision_b)
