@@ -1,6 +1,9 @@
 import re
 
-from bzrlib import patches
+from bzrlib import (
+    patches,
+    workingtree,
+    )
 
 from bzrlib.plugins.bzrtools import errors
 
@@ -28,8 +31,8 @@ class FilePatchSource(PatchSource):
 
 class BzrPatchSource(PatchSource):
     def __init__(self, revision=None, file_list=None):
-        from bzrlib.builtins import tree_files
-        self.tree, self.file_list = tree_files(file_list)
+        open_containing_paths = workingtree.WorkingTree.open_containing_paths
+        self.tree, self.file_list = open_containing_paths(file_list)
         self.base = self.tree.basedir
         self.revision = revision
 
