@@ -16,8 +16,6 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys
-import datetime
-from bzrlib.progress import ProgressBar
 
 class Progress(object):
     def __init__(self, units, current, total=None):
