@@ -1,11 +1,10 @@
 import os
 import sys
-import subprocess
 from datetime import datetime
-from errors import CommandError, PatchFailed, PatchInvokeError
+from errors import CommandError, PatchFailed
 from hunk_selector import ShelveHunkSelector, UnshelveHunkSelector
 from patch import run_patch
-from patchsource import PatchSource, FilePatchSource
+from patchsource import FilePatchSource
 from bzrlib.osutils import rename
 
 class Shelf(object):
