@@ -18,13 +18,18 @@
 import cmd
 from itertools import chain
 import os
-import readline
+try:
+    import readline
+except ImportError:
+    _has_readline = False
+else:
+    _has_readline = True
 import shlex
 import stat
 import string
 import sys
 
-from bzrlib import osutils
+from bzrlib import osutils, trace
 from bzrlib.branch import Branch
 from bzrlib.config import config_dir, ensure_config_dir_exists
 from bzrlib.commands import get_cmd_object, all_command_names, get_alias
@@ -100,14 +105,16 @@ class PromptCmd(cmd.Cmd):
         ensure_config_dir_exists()
         self.history_file = osutils.pathjoin(config_dir(), 'shell-history')
         whitespace = ''.join(c for c in string.whitespace if c < chr(127))
-        readline.set_completer_delims(whitespace)
-        if os.access(self.history_file, os.R_OK) and \
-            os.path.isfile(self.history_file):
-            readline.read_history_file(self.history_file)
+        if _has_readline:
+            readline.set_completer_delims(whitespace)
+            if os.access(self.history_file, os.R_OK) and \
+                os.path.isfile(self.history_file):
+                readline.read_history_file(self.history_file)
         self.cwd = os.getcwd()
 
     def write_history(self):
-        readline.write_history_file(self.history_file)
+        if _has_readline:
+            readline.write_history_file(self.history_file)
 
     def do_quit(self, args):
         self.write_history()
@@ -198,11 +205,12 @@ class PromptCmd(cmd.Cmd):
             else:
                 return (cmd_obj.run_argv_aliases(args, alias_args) or 0)
         except BzrError, e:
+            trace.log_exception_quietly()
             print e
         except KeyboardInterrupt, e:
             print "Interrupted"
         except Exception, e:
-#            print "Unhandled error:\n%s" % errors.exception_str(e)
+            trace.log_exception_quietly()
             print "Unhandled error:\n%s" % (e)
 
 
