@@ -6,12 +6,21 @@ from bzrlib import branch, osutils, workingtree
 from bzrlib.config import LocationConfig
 from bzrlib.transport import get_transport
 from bzrlib.tests import (
-    HardlinkFeature,
-    ModuleAvailableFeature,
     TestCaseWithTransport,
     )
 from bzrlib.plugins.bzrtools import command
 
+try:
+    from bzrlib.tests.features import (
+        HardlinkFeature,
+        ModuleAvailableFeature,
+        )
+except ImportError: # bzr < 2.5
+    from bzrlib.tests import (
+        HardlinkFeature,
+        ModuleAvailableFeature,
+        )
+
 
 LzmaFeature = ModuleAvailableFeature("lzma")
 
@@ -112,13 +121,13 @@ class TestBzrTools(TestCaseWithTransport):
         self.assertIs(False, os.path.exists('checkout2'))
         self.assertIs(False, os.path.exists('source2'))
 
-    def test_branches(self):
+    def test_list_branches(self):
         self.run_bzr('init source')
         self.run_bzr('init source/subsource')
         self.run_bzr('checkout --lightweight source checkout')
         self.run_bzr('init checkout/subcheckout')
         self.run_bzr('init checkout/.bzr/subcheckout')
-        out = self.run_bzr('branches')[0]
+        out = self.run_bzr('list-branches')[0]
         lines = out.split('\n')
         self.assertIs(True, 'source' in lines)
         self.assertIs(True, 'source/subsource' in lines)
