@@ -44,10 +44,10 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.tree.lock_read()
         try:
             old_date = _patch_header_date(old_tree,
-                                          old_tree.inventory.path2id(filename),
+                                          old_tree.path2id(filename),
                                           filename)
             new_date = _patch_header_date(self.tree,
-                self.tree.inventory.path2id(filename), filename)
+                self.tree.path2id(filename), filename)
         finally:
             self.tree.unlock()
             old_tree.unlock()
@@ -63,7 +63,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         old_tree.lock_read()
         try:
             old_date = _patch_header_date(old_tree,
-                                          old_tree.inventory.path2id(filename),
+                                          old_tree.path2id(filename),
                                           filename)
         finally:
             old_tree.unlock()
@@ -96,7 +96,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
             self.tree.lock_write()
             try:
                 new_date = _patch_header_date(self.tree,
-                    self.tree.inventory.path2id('test_file'), 'test_file')
+                    self.tree.path2id('test_file'), 'test_file')
             finally:
                 self.tree.unlock()
 
@@ -337,7 +337,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
             f.write(self.MODIFIED)
             f.close()
             new_date = _patch_header_date(self.tree,
-                self.tree.inventory.path2id('test_file'), 'test_file')
+                self.tree.path2id('test_file'), 'test_file')
         finally:
             self.tree.unlock()
 
@@ -438,10 +438,10 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.tree.lock_read()
         try:
             old_date = _patch_header_date(old_tree,
-                old_tree.inventory.path2id('test_file'),
+                old_tree.path2id('test_file'),
                                           'test_file')
             new_date = _patch_header_date(self.tree,
-                self.tree.inventory.path2id('test_file'), 'test_file')
+                self.tree.path2id('test_file'), 'test_file')
         finally:
             old_tree.unlock()
             self.tree.unlock()
