@@ -15,7 +15,7 @@ class TestCBranch(TestCaseWithTransport):
         config.set_user_option('cbranch_target',
                                'directory/subdirectory/target_branch')
         cbranch('source', 'target')
-        self.failUnlessExists('directory/subdirectory/target_branch')
+        self.assertPathExists('directory/subdirectory/target_branch')
 
 
 def test_suite():
