@@ -26,8 +26,11 @@ from bzrlib.plugins.bzrtools.upstream_import import (
 from bzrlib.tests import (
     TestCaseInTempDir,
     TestCaseWithTransport,
-    UnicodeFilenameFeature,
     )
+try:
+    from bzrlib.tests.features import UnicodeFilenameFeature
+except ImportError: # bzr < 2.5
+    from bzrlib.tests import UnicodeFilenameFeature
 
 
 def import_tar_broken(tree, tar_input):
@@ -220,9 +223,9 @@ class TestImport(TestCaseInTempDir):
             self.assertTrue(tree.path2id('README') is not None)
             self.assertTrue(tree.path2id('FEEDME') is not None)
             self.assertTrue(os.path.isfile(tree.abspath('README')))
-            self.assertEqual(tree.inventory[tree.path2id('README')].kind,
+            self.assertEqual(tree.stored_kind(tree.path2id('README')),
                 'file')
-            self.assertEqual(tree.inventory[tree.path2id('FEEDME')].kind,
+            self.assertEqual(tree.stored_kind(tree.path2id('FEEDME')),
                 'file')
             f = file(tree.abspath('junk/food'), 'wb')
             f.write('I like food\n')
