@@ -1,8 +1,8 @@
 """Import upstream source into a branch"""
 
-from bz2 import BZ2File
 import errno
 import os
+import re
 from StringIO import StringIO
 import stat
 import tarfile
@@ -17,6 +17,7 @@ from bzrlib.trace import warning
 from bzrlib.transform import TreeTransform, resolve_conflicts, cook_conflicts
 from bzrlib.workingtree import WorkingTree
 from bzrlib.plugins.bzrtools.bzrtools import open_from_url
+from bzrlib.plugins.bzrtools import errors
 
 class ZipFileWrapper(object):
 
@@ -182,12 +183,20 @@ def import_dir(tree, dir_input):
     dir_file = DirWrapper(dir_input)
     import_archive(tree, dir_file)
 
-def import_archive(tree, archive_file):
-    prefix = common_directory(names_of_files(archive_file))
-    tt = TreeTransform(tree)
 
+def import_archive(tree, archive_file):
+    tt = TreeTransform(tree)
+    try:
+        import_archive_to_transform(tree, archive_file, tt)
+        tt.apply()
+    finally:
+        tt.finalize()
+
+
+def import_archive_to_transform(tree, archive_file, tt):
+    prefix = common_directory(names_of_files(archive_file))
     removed = set()
-    for path, entry in tree.inventory.iter_entries():
+    for path, entry in tree.iter_entries_by_dir():
         if entry.parent_id is None:
             continue
         trans_id = tt.trans_id_tree_path(path)
@@ -201,7 +210,10 @@ def import_archive(tree, archive_file):
         if member.type == 'g':
             # type 'g' is a header
             continue
-        relative_path = member.name
+        # Inverse functionality in bzr uses utf-8.  We could also
+        # interpret relative to fs encoding, which would match native
+        # behaviour better.
+        relative_path = member.name.decode('utf-8')
         if prefix is not None:
             relative_path = relative_path[len(prefix)+1:]
             relative_path = relative_path.rstrip('/')
@@ -249,7 +261,6 @@ def import_archive(tree, archive_file):
 
     for conflict in cook_conflicts(resolve_conflicts(tt), tt):
         warning(conflict)
-    tt.apply()
 
 
 def do_import(source, tree_directory=None):
@@ -269,26 +280,56 @@ def do_import(source, tree_directory=None):
         if tree.changes_from(tree.basis_tree()).has_changed():
             raise BzrCommandError("Working tree has uncommitted changes.")
 
-        if (source.endswith('.tar') or source.endswith('.tar.gz') or
-            source.endswith('.tar.bz2')) or source.endswith('.tgz'):
-            try:
-                tar_input = open_from_url(source)
-                if source.endswith('.bz2'):
-                    tar_input = StringIO(tar_input.read().decode('bz2'))
-            except IOError, e:
-                if e.errno == errno.ENOENT:
-                    raise NoSuchFile(source)
-            try:
-                import_tar(tree, tar_input)
-            finally:
-                tar_input.close()
-        elif source.endswith('.zip'):
-            import_zip(tree, open_from_url(source))
-        elif file_kind(source) == 'directory':
-            s = StringIO(source)
-            s.seek(0)
-            import_dir(tree, s)
+        try:
+            archive, external_compressor = get_archive_type(source)
+        except errors.NotArchiveType:
+            if file_kind(source) == 'directory':
+                s = StringIO(source)
+                s.seek(0)
+                import_dir(tree, s)
+            else:
+                raise BzrCommandError('Unhandled import source')
         else:
-            raise BzrCommandError('Unhandled import source')
+            if archive == 'zip':
+                import_zip(tree, open_from_url(source))
+            elif archive == 'tar':
+                try:
+                    tar_input = open_from_url(source)
+                    if external_compressor == 'bz2':
+                        import bz2
+                        tar_input = StringIO(bz2.decompress(tar_input.read()))
+                    elif external_compressor == 'lzma':
+                        import lzma
+                        tar_input = StringIO(lzma.decompress(tar_input.read()))
+                except IOError, e:
+                    if e.errno == errno.ENOENT:
+                        raise NoSuchFile(source)
+                try:
+                    import_tar(tree, tar_input)
+                finally:
+                    tar_input.close()
     finally:
         tree.unlock()
+
+
+def get_archive_type(path):
+    """Return the type of archive and compressor indicated by path name.
+
+    Only external compressors are returned, so zip files are only
+    ('zip', None).  .tgz is treated as ('tar', 'gz') and '.tar.xz' is treated
+    as ('tar', 'lzma').
+    """
+    matches = re.match(r'.*\.(zip|tgz|tar(.(gz|bz2|lzma|xz))?)$', path)
+    if not matches:
+        raise errors.NotArchiveType(path)
+    external_compressor = None
+    if matches.group(3) is not None:
+        archive = 'tar'
+        external_compressor = matches.group(3)
+        if external_compressor == 'xz':
+            external_compressor = 'lzma'
+    elif matches.group(1) == 'tgz':
+        return 'tar', 'gz'
+    else:
+        archive = matches.group(1)
+    return archive, external_compressor
