@@ -1,21 +1,5 @@
 import sys
-
-if sys.platform == "win32":
-    import msvcrt
-    def getchar():
-        return msvcrt.getch()
-else:
-    import tty
-    import termios
-    def getchar():
-        fd = sys.stdin.fileno()
-        settings = termios.tcgetattr(fd)
-        try:
-            tty.setraw(fd)
-            ch = sys.stdin.read(1)
-        finally:
-            termios.tcsetattr(fd, termios.TCSADRAIN, settings)
-        return ch
+from bzrlib.osutils import getchar
 
 
 class UserOption:
